fnss.topologies.topology.Topology.size — FNSS 0.6.1 documentation

### Navigation

- index
- modules |
- modules |
- FNSS 0.6.1 documentation »

# fnss.topologies.topology.Topology.size

`Topology.` `size`(weight=None)

  Return the number of edges.

  Parameters: | weight : string or None, optional (default=None) The edge attribute that holds the numerical value used as a weight. If None, then each edge has weight 1.
  Returns: | nedges : int The number of edges or sum of edge weights in the graph.

  See also

  `number_of_edges`

  Examples

      >>> G = nx.Graph()   # or DiGraph, MultiGraph, MultiDiGraph, etc
      >>> G.add_path([0,1,2,3])
      >>> G.size()
      3

      >>> G = nx.Graph()   # or DiGraph, MultiGraph, MultiDiGraph, etc
      >>> G.add_edge('a','b',weight=2)
      >>> G.add_edge('b','c',weight=4)
      >>> G.size()
      2
      >>> G.size(weight='weight')
      6.0

### Navigation

- index
- modules |
- modules |
- FNSS 0.6.1 documentation »